# Authors

## Maintainers

Matteo Bunino \<[matteo.bunino@cern.ch](mailto:matteo.bunino@cern.ch)\>  
Rakesh Sarma \<[r.sarma@fz-juelich.de](mailto:r.sarma@fz-juelich.de)\>
Mario Ruettgers \<[m.ruettgers@fz-juelich.de](mailto:m.ruettgers@fz-juelich.de)\>
Kalliopi Tsolaki \<[kalliopi.tsolaki@cern.ch](mailto:kalliopi.tsolaki@cern.ch)\>

## Contributors

[All contributors](https://github.com/interTwin-eu/T6.5-AI-and-ML/graphs/contributors)
